From: Ingo Molnar <mingo@elte.hu>
To: Alexey Dobriyan <adobriyan@gmail.com>
Cc: torvalds@osdl.org, viro@zeniv.linux.org.uk,
acme@ghostprotocols.net, linux-kernel@vger.kernel.org
Subject: Re: [PATCH 2/2] headers: reduction in interrupt.h
Date: Wed, 29 Oct 2008 07:21:00 +0100 [thread overview]
Message-ID: <20081029062100.GB7936@elte.hu> (raw)
In-Reply-To: <20081029044524.GC2304@x200.localdomain>
* Alexey Dobriyan <adobriyan@gmail.com> wrote:
> >From 2255be0a5f55ffd58b0ebdf456cf77b7258889fe Mon Sep 17 00:00:00 2001
> From: Alexey Dobriyan <adobriyan@gmail.com>
> Date: Wed, 29 Oct 2008 06:41:45 +0300
> Subject: [PATCH 2/2] headers: reduction in interrupt.h
>
> 1. remove sched.h from interrupt.h, it's not needed for anything
> 2. remove sched.h from smp_lock.h, so (1) won't be a lie due to
>
> linux/interrupt.h => linux/hardirq.h => linux/smp_lock.h => linux/sched.h
>
> After static inline reacquire_kernel_lock() was moved from there, inclusion
> isn't needed.
> 3. remove also kernel.h, linkage.h, preempt.h, smp.h, asm/ptrace.h inclusions,
> I manually checked every token.
> 4. fix fallout
>
> The end result is that, e.g. i386 allyesconfig kernel shrinks (with all those
> bloated debuginfo sections) from 604.1 MB to 593.1 MB (-1.8 %).
>
> Compile time should also improve simply because compiler will parse less.
>
> Cross-compile tested on 469 configs, big and small, across many arches
> and a dozen of randconfigs.
very nice! Regarding my previous mail, we can move the BKL interfaces
away from sched.c in another patch, i dont want this very cool header
cleanup be held up.
Acked-by: Ingo Molnar <mingo@elte.hu>
Ingo
next prev parent reply other threads:[~2008-10-29 6:21 UTC|newest]
Thread overview: 9+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-10-29 4:43 [GIT] headers redux Alexey Dobriyan
2008-10-29 4:44 ` [PATCH 1/2] headers: move release_kernel_lock(), reacquire_kernel_lock() to sched.c Alexey Dobriyan
2008-10-29 4:45 ` [PATCH 2/2] headers: reduction in interrupt.h Alexey Dobriyan
2008-10-29 6:21 ` Ingo Molnar [this message]
2008-10-29 6:18 ` [PATCH 1/2] headers: move release_kernel_lock(), reacquire_kernel_lock() to sched.c Ingo Molnar
2008-10-29 6:29 ` Harvey Harrison
2008-10-29 10:04 ` Christoph Hellwig
2008-10-29 13:14 ` Alexey Dobriyan
2008-10-29 16:42 ` Ingo Molnar
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20081029062100.GB7936@elte.hu \
--to=mingo@elte.hu \
--cc=acme@ghostprotocols.net \
--cc=adobriyan@gmail.com \
--cc=linux-kernel@vger.kernel.org \
--cc=torvalds@osdl.org \
--cc=viro@zeniv.linux.org.uk \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®